# Fetch Oracle Client Contract

## Description

This contract package is used to interface with a Fetch Oracle Client contract, which requests a real-world value from a Fetch Oracle contract.

## Functions

* `queryOracleValue()`: call contract method that requests oracle value from associated oracle contract